@@ -1,6 +1,6 @@
 // 2006-10-12  Paolo Carlini  <pcarlini@suse.de>
 
-// Copyright (C) 2006-2024 Free Software Foundation, Inc.
+// Copyright (C) 2006-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -35,11 +35,12 @@ void test01()
   using namespace std;
 
   ostringstream oss_01;
+  const string str_01(50, 'a');
 
   oss_01.width(WIDTH);
   const streamsize width = oss_01.width();
 
-  oss_01 << 'a';
+  oss_01 << str_01.c_str();
 
   VERIFY( oss_01.good() );
   VERIFY( oss_01.str().size() == string::size_type(width) );
