@@ -1,6 +1,6 @@
-// 2006-07-15  Paolo Carlini  <pcarlini@suse.de>
+// 2006-10-12  Paolo Carlini  <pcarlini@suse.de>
 
-// Copyright (C) 2006-2024 Free Software Foundation, Inc.
+// Copyright (C) 2006-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -35,12 +35,15 @@ void test01()
   using namespace std;
 
   wostringstream oss_01;
-  const string str_01(MAX_SIZE, 'a');
+  const string str_01(50, 'a');
+
+  oss_01.width(MAX_SIZE);
+  const streamsize width = oss_01.width();
 
   oss_01 << str_01.c_str();
 
   VERIFY( oss_01.good() );
-  VERIFY( oss_01.str().size() == str_01.size() );
+  VERIFY( oss_01.str().size() == wstring::size_type(width) );
 }
 
 int main()
