@@ -1,4 +1,4 @@
-// 2003-02-26  Carlo Wood  <carlo@alinoe.com>
+// 2003-02-26 Benjamin Kosnik <bkoz@redhat.com>
 
 // Copyright (C) 2003-2025 Free Software Foundation, Inc.
 //
@@ -21,17 +21,14 @@
 
 #include <testsuite_hooks.h>
 
-// c++/3111
+// libstdc++/7986
 int main()
 {
   using namespace __gnu_test;
 
-  // cplus-dem FAIL
-  // icc FAIL
-  // verify_demangle("_Z1fAszL_ZZNK1N1A1fEvE3foo_0E_i", 
-  //       "f(int[sizeof(N::A::f() const::foo())])");
-  verify_demangle("_Z1fAszL_ZZNK1N1A1fEvE3foo_0E_i", 
-		  "f(int [sizeof (N::A::f() const::foo)])");
+  // Equivalent, but formatting difference in void argument.
+  //  verify_demangle("_Z1fM1AFivEPS0_", "f(int (A::*)(void), int (*)(void))");
+  verify_demangle("_Z1fM1AFivEPS0_", "f(int (A::*)(), int (*)())");
 
   return 0;
 }
